@@ -9,14 +9,15 @@ import logging
 import sys
 
 import cemba_data
+from cemba_data import __version__
 
 log = logging.getLogger()
 
 DESCRIPTION = """
-YAP (Yet Another Pipeline) is an in-house mapping pipeline for 
-snmC-seq, NOMe-seq, snmCT-seq mapping and preprocessing.
+YAP (Yet Another Pipeline) is a mapping pipeline for multiple
+snmC-seq based single-cell sequencing technologies.
 
-See documentation at https://cemba-data.readthedocs.io
+See documentation at https://hq-1.gitbook.io/mc/
 """
 
 EPILOG = """
@@ -203,6 +204,13 @@ def sbatch_register_subparser(subparser):
         help="Max number of jobs for the same user (not for the same sbatch command). "
              "If not provided, will determine automatically based on stampede2 limits."
     )
+
+    parser.add_argument(
+        "--dry_run",
+        required=False,
+        action='store_true',
+        help="Prepare scripts for sbatch manual submission or debug."
+    )
     return
 
 
@@ -291,7 +299,8 @@ def demultiplex_register_subparser(subparser):
         '-j',
         type=int,
         required=True,
-        help="Number of cores to use. Note that the demultiplex step will only use at most 16 cores."
+        help="Number of cores to use. Note that the demultiplex step will only use at most 32 cores, "
+             "the merge lane step will use the number of cores you provided."
     )
     return
 
@@ -366,10 +375,11 @@ def print_default_config_register_subparser(subparser):
     return
 
 
-def prepare_register_subparser(subparser):
-    parser = subparser.add_parser('prepare',
+def start_from_cell_fastq_register_subparser(subparser):
+    parser = subparser.add_parser('start-from-cell-fastq',
                                   formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-                                  help="Prepare batch jobs.")
+                                  help="Prepare batch jobs directly from cell-level FASTQ files, "
+                                       "no demultiplex step.")
 
     parser_req = parser.add_argument_group("Required inputs")
 
@@ -381,37 +391,20 @@ def prepare_register_subparser(subparser):
         help="Pipeline output directory, if not exist, will create recursively."
     )
 
-    parser.add_argument(
-        "--name",
+    parser_req.add_argument(
+        "--config_path",
+        "-config",
         type=str,
-        default=None,
-        help="Name of the project, if None, will use the output_dir name."
+        required=True,
+        help="Path to the mapping config, see 'yap default-mapping-config' about how to generate this file."
     )
 
-    parser.add_argument(
-        "--total_jobs",
-        "-j",
-        type=int,
-        default=20,
-        help="Total number of jobs run in parallel."
-    )
-
-    parser.add_argument(
-        "--cores_per_job",
-        "-c",
-        type=int,
-        default=5,
-        help="Number of cores used by each job, total number of cores is (cores_per_job * total_jobs)."
-    )
-
-    parser.add_argument(
-        "--memory_gb_per_core",
-        "-m",
+    parser_req.add_argument(
+        "--fastq_pattern",
+        "-fq",
         type=str,
-        default='5G',
-        help="Memory (GB) assigned to each core, "
-             "the total memory of each job is (cores_per_job * memory_per_core); "
-             "the total memory of all jobs is (cores_per_job * memory_per_core * total_jobs)"
+        required=True,
+        help="Path pattern with wildcard to match all cell-level FASTQ files, pattern with wildcard must be quoted."
     )
     return
 
@@ -446,6 +439,8 @@ def main():
     parser = argparse.ArgumentParser(description=DESCRIPTION,
                                      epilog=EPILOG,
                                      formatter_class=argparse.RawDescriptionHelpFormatter)
+    parser.add_argument("--version", action="version", help="Show version number and exit",
+                        version=__version__)
     subparsers = parser.add_subparsers(
         title="functions",
         dest="command",
@@ -459,7 +454,7 @@ def main():
     print_plate_info_register_subparser(subparsers)
     make_sample_sheet_register_subparser(subparsers)
     demultiplex_register_subparser(subparsers)
-    prepare_register_subparser(subparsers)
+    start_from_cell_fastq_register_subparser(subparsers)
     summary_register_subparser(subparsers)
 
     # initiate
@@ -497,8 +492,8 @@ def main():
         from .demultiplex import demultiplex_pipeline as func
     elif cur_command == 'default-mapping-config':
         from .mapping import print_default_mapping_config as func
-    elif cur_command == 'prepare':
-        from .mapping import prepare_run as func
+    elif cur_command == 'start-from-cell-fastq':
+        from .mapping import start_from_cell_fastq as func
     elif cur_command == 'summary':
         from cemba_data.mapping import final_summary as func
     else:
